@@ -25,6 +25,8 @@ sub AutoResult_around_result_GET {
         },
     };
 
+    my $return_data_as = $self->config->{return_data_as} ? lc $self->config->{return_data_as} : 'array';
+
     my $name = $self->config->{data_related_as};
     my $func = $self->config->{build_row};
 
@@ -33,6 +35,8 @@ sub AutoResult_around_result_GET {
         push @{ $ref->{data} }, $ret;
     }
 
+    $ref->{data} = $ref->{data}[0] if ( $return_data_as eq 'hash' && !exists $c->req->params->{with_history} );
+
     $self->status_ok( $c, entity => $ref );
 
     $self->$orig(@_);
